@@ -8,7 +8,7 @@ import tarfile
 from contextlib import contextmanager
 from os import PathLike
 from tempfile import TemporaryFile
-from typing import IO, Dict, Generator, List, Sequence, TypeVar, Union, cast
+from typing import IO, Container as AbstractContainer, Dict, Generator, List, Optional, Sequence, TypeVar, Union, cast
 
 import docker
 from docker import DockerClient
@@ -18,7 +18,7 @@ from docker.models.networks import Network
 from requests import HTTPError
 
 __all__ = ['get_ports', 'get_aliases', 'is_alive', 'is_removed', 'killing', 'create_and_pull',
-           'download_file', 'upload_file', 'SafeContainerCreator']
+           'download_file', 'upload_file', 'SafeContainerCreator', 'removing']
 
 _DEFAULT_TIMEOUT = 10
 
@@ -121,6 +121,46 @@ def killing(container: _CT, *, timeout: float = _DEFAULT_TIMEOUT,
             container.wait(timeout=timeout)
 
 
+@contextmanager
+def removing(container: _CT, *, expected_exit_code: Optional[Union[int, AbstractContainer[int]]] = 0, force=False) \
+        -> Generator[_CT, None, None]:
+    """A context manager that removes a docker container upon completion.
+
+    Example:
+        container = DockerContainer(...)
+        with removing(container):
+            ...
+        # Container is now removed
+
+    Args:
+        container: Container to remove upon completion
+        expected_exit_code: Expected exit code or codes of the container. If the container exited with a different
+            code, an exception will be raised. Defaults to 0.
+        force: If True, the container will be stopped and removed even if it is running.
+
+    Returns:
+        A context manager to be used in a 'with' statement.
+    """
+    try:
+        yield container
+    finally:
+        if is_removed(container):
+            return
+        # checking if the container is removed reloads the container
+        if is_alive(container):
+            if not force:
+                raise RuntimeError(f"Container {container.id} is still alive (status: {container.status})")
+            container.kill('SIGKILL')
+        result = container.wait(timeout=10)
+        if expected_exit_code is not None:
+            if isinstance(expected_exit_code, int):
+                expected_exit_code = (expected_exit_code,)
+
+            if result['StatusCode'] not in expected_exit_code:
+                raise RuntimeError(f"Container {container.id} exited with code {result['StatusCode']}")
+        container.remove(force=force, v=True)
+
+
 def create_and_pull(docker_client: DockerClient, image: str, *args, **kwargs) -> Container:
     """
     Create a docker container, pulling the image if necessary.
@@ -156,8 +196,7 @@ def is_removed(container: Container):
     return False
 
 
-def download_file(container: Container, path: Union[str, PathLike[str]]
-                  ) -> IO[bytes]:
+def download_file(container: Container, path: Union[str, PathLike]) -> IO[bytes]:
     """Download a file from the given container
 
     Args:
@@ -255,6 +294,7 @@ class SafeContainerCreator:
     A class that can safely pull and create multiple containers in succession, where if one fails, all the previous
      ones are removed
     """
+
     def __init__(self, client: DockerClient):
         self.client = client
         self.created: List[Container] = []
