@@ -1,9 +1,10 @@
 from yellowbox.extras.webserver.class_endpoint import class_http_endpoint, class_ws_endpoint
 from yellowbox.extras.webserver.endpoints import MockHTTPEndpoint, MockWSEndpoint, http_endpoint, ws_endpoint
 from yellowbox.extras.webserver.http_request_capture import ExpectedHTTPRequest
-from yellowbox.extras.webserver.util import iter_side_effects
+from yellowbox.extras.webserver.util import iter_side_effects, verbose_http_side_effect
 from yellowbox.extras.webserver.webserver import WebServer
 from yellowbox.extras.webserver.ws_request_capture import ExpectedWSTranscript, Sender
 
 __all__ = ['WebServer', 'http_endpoint', 'ws_endpoint', 'ExpectedHTTPRequest', 'ExpectedWSTranscript', 'Sender',
-           'MockHTTPEndpoint', 'MockWSEndpoint', 'class_ws_endpoint', 'class_http_endpoint', 'iter_side_effects']
+           'MockHTTPEndpoint', 'MockWSEndpoint', 'class_ws_endpoint', 'class_http_endpoint', 'iter_side_effects',
+           'verbose_http_side_effect']
